.. _diffusion-examples-index:

diffusion
=========

.. toctree::
   :maxdepth: 2

   cube.py <diffusion-cube>
   darcy_flow_multicomp.py <diffusion-darcy_flow_multicomp>
   laplace_1d.py <diffusion-laplace_1d>
   laplace_coupling_lcbcs.py <diffusion-laplace_coupling_lcbcs>
   laplace_fluid_2d.py <diffusion-laplace_fluid_2d>
   laplace_iga_interactive.py <diffusion-laplace_iga_interactive>
   laplace_refine_interactive.py <diffusion-laplace_refine_interactive>
   laplace_shifted_periodic.py <diffusion-laplace_shifted_periodic>
   laplace_time_ebcs.py <diffusion-laplace_time_ebcs>
   poisson.py <diffusion-poisson>
   poisson_field_dependent_material.py <diffusion-poisson_field_dependent_material>
   poisson_functions.py <diffusion-poisson_functions>
   poisson_iga.py <diffusion-poisson_iga>
   poisson_neumann.py <diffusion-poisson_neumann>
   poisson_nonlinear_material.py <diffusion-poisson_nonlinear_material>
   poisson_parallel_interactive.py <diffusion-poisson_parallel_interactive>
   poisson_parametric_study.py <diffusion-poisson_parametric_study>
   poisson_periodic_boundary_condition.py <diffusion-poisson_periodic_boundary_condition>
   poisson_short_syntax.py <diffusion-poisson_short_syntax>
   sinbc.py <diffusion-sinbc>
   time_advection_diffusion.py <diffusion-time_advection_diffusion>
   time_heat_equation_multi_material.py <diffusion-time_heat_equation_multi_material>
   time_poisson.py <diffusion-time_poisson>
   time_poisson_explicit.py <diffusion-time_poisson_explicit>
   time_poisson_interactive.py <diffusion-time_poisson_interactive>
